==> graphstorm-0.3-py3-none-any.whl: graphstorm/wholegraph/utils.py <==
"""
    Copyright 2023 Contributors

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Utils for integrating WholeGraph into GraphStorm
"""


def is_wholegraph_embedding(data):
    """ Check if the data is in WholeMemory emedding format which
        is required to use wholegraph framework.
    """
    try:
        import pylibwholegraph
        return isinstance(data, pylibwholegraph.torch.WholeMemoryEmbedding)
    except ImportError:
        return False


def is_wholegraph_embedding_module(data):
    """Check if the data is in WholeMemory emedding format which
    is required to use wholegraph framework.
    """
    try:
        import pylibwholegraph
        return isinstance(data, pylibwholegraph.torch.WholeMemoryEmbeddingModule)
    except:  # pylint: disable=bare-except
        return False


def is_wholegraph_optimizer(data):
    """Check if the data is in WholeMemoryOptimizer format which
    is required to use wholegraph framework.
    """
    try:
        import pylibwholegraph
        return isinstance(data, pylibwholegraph.torch.WholeMemoryOptimizer)
    except:  # pylint: disable=bare-except
        return False

==> graphstorm-0.4.0-py3-none-any.whl: graphstorm/wholegraph/utils.py <==
"""
    Copyright 2023 Contributors

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Utils for integrating WholeGraph into GraphStorm
"""


def is_wholegraph_embedding(data):
    """ Check if the data is in WholeMemory emedding format which
        is required to use wholegraph framework.
    """
    try:
        import pylibwholegraph.torch
        return isinstance(data, pylibwholegraph.torch.WholeMemoryEmbedding)
    except ImportError:
        return False


def is_wholegraph_embedding_module(data):
    """Check if the data is in WholeMemory emedding format which
    is required to use wholegraph framework.
    """
    try:
        import pylibwholegraph.torch
        return isinstance(data, pylibwholegraph.torch.WholeMemoryEmbeddingModule)
    except:  # pylint: disable=bare-except
        return False


def is_wholegraph_optimizer(data):
    """Check if the data is in WholeMemoryOptimizer format which
    is required to use wholegraph framework.
    """
    try:
        import pylibwholegraph.torch
        return isinstance(data, pylibwholegraph.torch.WholeMemoryOptimizer)
    except:  # pylint: disable=bare-except
        return False
